Index: net/quic/quic_framer.h |
diff --git a/net/quic/quic_framer.h b/net/quic/quic_framer.h |
index 4cda9dcc2a915cf60a0923d903a2ee84272c6afb..f403e14dd06a3f9d2ba6a1ec84dd682c55e152a3 100644 |
--- a/net/quic/quic_framer.h |
+++ b/net/quic/quic_framer.h |
@@ -95,10 +95,10 @@ class NET_EXPORT_PRIVATE QuicFramer { |
virtual ~QuicFramer(); |
// Calculates the largest received packet to advertise in the case an Ack |
// Frame was truncated. last_written in this case is the iterator for the |
// last missing packet which fit in the outgoing ack. |
- static QuicPacketSequenceNumber CalculateLargestReceived( |
+ static QuicPacketSequenceNumber CalculateLargestObserved( |
const SequenceSet& missing_packets, |
SequenceSet::const_iterator last_written); |
@@ -95,10 +95,10 @@ class NET_EXPORT_PRIVATE QuicFramer { |
virtual ~QuicFramer(); |
- // Calculates the largest received packet to advertise in the case an Ack |
+ // Calculates the largest observed packet to advertise in the case an Ack |
// Frame was truncated. last_written in this case is the iterator for the |
// last missing packet which fit in the outgoing ack. |